Running AHFCTL Commands to Manage InfiniBand and RoCE Switches
Use the ahfctl commands to manage InfiniBand and RoCE switches.
Note:
Only the AHF install user with the root user privileges can manage switch configurations.
ahfctl switch
Use the ahfctl switch command to manage manage InfiniBand and RoCE switches.
Syntax
ahfctl switch
[-h]
[-configure]
[-switches SWITCHES]
[-status]
[-json]
[-deconfigure]
[-debug]
Parameters
ahfctl switch Command Parameters
| Parameter | Description |
|---|---|
-configure | Specify to configure InfiniBand and RoCE switches. |
-switches SWITCHES | Specify a comma-delimited list of switches to configure. For example: switch1,switch2,switch3 |
-status | Specify to get configuration details of InfiniBand and RoCE switches. |
-json | Specify to get configuration details of InfiniBand and RoCE switches in JSON format. |
-deconfigure | Specify to remove configuration details of InfiniBand and RoCE switches from AHF. |
-debug | Specify to run the debug script. |
Examples ahfctl switch examples
To configure InfiniBand and RoCE switches:
ahfctl switch -configureTo store configuration details of the switches specified:
ahfctl switch -configure -switches sw1,sw2,sw3To get configuration details of a switch:
ahfctl switch -statusTo get configuration details of a switch in JSON format:
ahfctl switch -status -jsonTo remove configuration details of a switch from AHF:
ahfctl switch -deconfigure
If security policies do not permit connection to an InfiniBand switch as the default user root, then specify a different user by setting the RAT_IBSWITCH_USER environment variable:
export RAT_IBSWITCH_USER=user
If security policies do not permit connection to a RoCE switch as the default user admin, then specify a different user by setting the RAT_IBSWITCH_USER environment variable:
export RAT_IBSWITCH_USER=user
Note:
AHF does not discover RoCE switches automatically. You must provide a list of available switches using the RAT_SWITCHES environment variable or while running the ahfctl switch -configure command.
export RAT_SWITCHES="scaqap06sw-roceb1,scaqap06sw-rocea1"
ahfctl switch -configure -switches sw1,sw2,sw3
You can also configure RoCE switches by running the ahfctl switch -configure command without specifying a comma-delimited list of RoCE switches. When you run the ahfctl switch -configure command, AHF will prompt you to enter a comma-delimited list switch names.